@@ -123,6 +123,8 @@ class DefaultTranslator(ITranslator):
             default=default,
             default_plural=default_plural,
             translations={},
+            context="<no context>",
+            has_plural=False,
         )
 
     def _get_singular_or_plural(
